frequency: Set global variable for column name.

.frequencyR Documentation

Set global variable for column name.

Description

Set global variable for column name or graphs tile.

Details

Set global variable for column name or graphs tile.


epiDisplay documentation built on Feb. 26, 2026, 1:08 a.m.