| .frequency1 | R Documentation |
Set global variable for column name in codebook function.
Set global variable for column name in codebook function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.