percent: Set global variable for column name in graph.

.percentR Documentation

Set global variable for column name in graph.

Description

Set global variable for column name in graph function.

Details

Set global variable for column name in graph function.


epiDisplay documentation built on Feb. 26, 2026, 1:08 a.m.