| .percent | R Documentation |
Set global variable for column name in graph function.
Set global variable for column name in graph function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.